import { AccountMeta, Context, PublicKey } from '@metaplex-foundation/umi';
import { LifecycleHookInitInfoArgs, LifecycleHookPlugin, LifecycleHookUpdateInfoArgs } from '.';
import { BaseExternalPluginInitInfoArgs, BaseExternalPluginKey, BaseExternalPluginUpdateInfoArgs, ExternalRegistryRecord } from '../generated';
import { DataStoreInitInfoArgs, DataStorePlugin, DataStoreUpdateInfoArgs } from './dataStore';
import { LifecycleChecksContainer, LifecycleEvent } from './lifecycleChecks';
import { OracleInitInfoArgs, OraclePlugin, OracleUpdateInfoArgs } from './oracle';
import { BasePlugin } from './types';
export type ExternalPluginTypeString = BaseExternalPluginKey['__kind'];
export type BaseExternalPlugin = BasePlugin & LifecycleChecksContainer;
export type ExternalPluginsList = {
    oracles?: OraclePlugin[];
    dataStores?: DataStorePlugin[];
    lifecycleHooks?: LifecycleHookPlugin[];
};
export type ExternalPluginInitInfoArgs = ({
    type: 'Oracle';
} & OracleInitInfoArgs) | ({
    type: 'LifecycleHook';
} & LifecycleHookInitInfoArgs) | ({
    type: 'DataStore';
} & DataStoreInitInfoArgs);
export type ExternalPluginUpdateInfoArgs = ({
    type: 'Oracle';
} & OracleUpdateInfoArgs) | ({
    type: 'LifecycleHook';
} & LifecycleHookUpdateInfoArgs) | ({
    type: 'DataStore';
} & DataStoreUpdateInfoArgs);
export declare const externalPluginManifests: {
    Oracle: import("./externalPluginManifest").ExternalPluginManifest<import("./oracle").Oracle, import("../generated").BaseOracle, OracleInitInfoArgs, import("../generated").BaseOracleInitInfoArgs, OracleUpdateInfoArgs, import("../generated").BaseOracleUpdateInfoArgs>;
    DataStore: import("./externalPluginManifest").ExternalPluginManifest<import("./dataStore").DataStore, import("../generated").BaseDataStore, DataStoreInitInfoArgs, import("../generated").BaseDataStoreInitInfoArgs, DataStoreUpdateInfoArgs, import("../generated").BaseDataStoreUpdateInfoArgs>;
    LifecycleHook: import("./externalPluginManifest").ExternalPluginManifest<import("./lifecycleHook").LifecycleHook, import("../generated").BaseLifecycleHook, LifecycleHookInitInfoArgs, import("../generated").BaseLifecycleHookInitInfoArgs, LifecycleHookUpdateInfoArgs, import("../generated").BaseLifecycleHookUpdateInfoArgs>;
};
export type ExternalPluginData = {
    dataLen: bigint;
    dataOffset: bigint;
};
export declare function externalRegistryRecordsToExternalPluginList(records: ExternalRegistryRecord[], accountData: Uint8Array): ExternalPluginsList;
export declare const isExternalPluginType: (plugin: {
    type: string;
}) => boolean;
export declare function createExternalPluginInitInfo({ type, ...args }: ExternalPluginInitInfoArgs): BaseExternalPluginInitInfoArgs;
export declare function createExternalPluginUpdateInfo({ type, ...args }: ExternalPluginUpdateInfoArgs): BaseExternalPluginUpdateInfoArgs;
export declare const findExtraAccounts: (context: Pick<Context, 'eddsa'>, lifecycle: LifecycleEvent, externalPlugins: ExternalPluginsList, inputs: {
    asset: PublicKey;
    collection?: PublicKey;
    owner: PublicKey;
    recipient?: PublicKey;
}) => AccountMeta[];
