import { Context, PublicKey } from '@metaplex-foundation/umi';
import { ExtraAccount } from './extraAccount';
import { BaseOracle, BaseOracleInitInfoArgs, BaseOracleUpdateInfoArgs, ExternalRegistryRecord, OracleValidation } from '../generated';
import { LifecycleChecks } from './lifecycleChecks';
import { PluginAuthority } from './pluginAuthority';
import { ExternalPluginManifest } from './externalPluginManifest';
import { BaseExternalPlugin } from './externalPlugins';
import { ExternalPluginKey } from './externalPluginKey';
import { ValidationResultsOffset } from './validationResultsOffset';
export type Oracle = Omit<BaseOracle, 'pda' | 'resultsOffset'> & {
    pda?: ExtraAccount;
    resultsOffset: ValidationResultsOffset;
};
export type OraclePlugin = BaseExternalPlugin & Oracle & {
    type: 'Oracle';
};
export type OracleInitInfoArgs = Omit<BaseOracleInitInfoArgs, 'initPluginAuthority' | 'lifecycleChecks' | 'pda' | 'resultsOffset'> & {
    type: 'Oracle';
    initPluginAuthority?: PluginAuthority;
    lifecycleChecks: LifecycleChecks;
    pda?: ExtraAccount;
    resultsOffset?: ValidationResultsOffset;
};
export type OracleUpdateInfoArgs = Omit<BaseOracleUpdateInfoArgs, 'lifecycleChecks' | 'pda' | 'resultsOffset'> & {
    key: ExternalPluginKey;
    lifecycleChecks?: LifecycleChecks;
    pda?: ExtraAccount;
    resultsOffset?: ValidationResultsOffset;
};
export declare function oracleInitInfoArgsToBase(o: OracleInitInfoArgs): BaseOracleInitInfoArgs;
export declare function oracleUpdateInfoArgsToBase(o: OracleUpdateInfoArgs): BaseOracleUpdateInfoArgs;
export declare function oracleFromBase(s: BaseOracle, r: ExternalRegistryRecord, account: Uint8Array): Oracle;
export declare function findOracleAccount(context: Pick<Context, 'eddsa'>, oracle: Pick<Oracle, 'baseAddress' | 'pda'>, inputs: {
    asset?: PublicKey;
    collection?: PublicKey;
    recipient?: PublicKey;
    owner?: PublicKey;
}): PublicKey;
export declare function deserializeOracleValidation(data: Uint8Array, offset: ValidationResultsOffset): OracleValidation;
export declare const oracleManifest: ExternalPluginManifest<Oracle, BaseOracle, OracleInitInfoArgs, BaseOracleInitInfoArgs, OracleUpdateInfoArgs, BaseOracleUpdateInfoArgs>;
